import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/rightsOrder/export")
def order_rightsorder_export(rightsType=None, userId=None, receiveDateEnd=None, orderMainId=None, payDateBegin=None, receiveDateBegin=None, mobile=None, payDateEnd=None, rightsOrderId=None, useStatus=None, headers=None, **kwargs):
    """
    权益订单导出接口-Y
    up_time=1675414281

    params: userId :  : 用户ID
    params: mobile :  : 手机号码
    params: rightsOrderId :  : 权益订单ID
    params: orderMainId :  : 主订单ID
    params: useStatus :  : 权益使用状态
    params: rightsType :  : 权益类型
    params: receiveDateBegin :  : 权益领取时间 - 开始
    params: receiveDateEnd :  : 权益领取时间 - 结束
    params: payDateBegin :  : 权益支付时间 - 开始
    params: payDateEnd :  : 权益支付时间 - 结束
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/order/rightsOrder/export"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
        "mobile": mobile,  # 手机号码
        "rightsOrderId": rightsOrderId,  # 权益订单ID
        "orderMainId": orderMainId,  # 主订单ID
        "useStatus": useStatus,  # 权益使用状态
        "rightsType": rightsType,  # 权益类型
        "receiveDateBegin": receiveDateBegin,  # 权益领取时间 - 开始
        "receiveDateEnd": receiveDateEnd,  # 权益领取时间 - 结束
        "payDateBegin": payDateBegin,  # 权益支付时间 - 开始
        "payDateEnd": payDateEnd,  # 权益支付时间 - 结束
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rightsOrder/insert")
def order_rightsorder_insert(rightsId=None, rightsName=None, rightsType=None, userId=None, refundDate=None, createTime=None, receiveDate=None, refundBillNo=None, updateId=None, payBillNo=None, payDate=None, mobile=None, payAmount=None, createBy=None, rightsOrderId=None, updateTime=None, orderMainId=None, useStatus=None, headers=None, **kwargs):
    """
    权益订单 - 新增-Y
    up_time=1675413078

    params: rightsOrderId : number : 权益订单ID
    params: rightsId : number : 权益ID
    params: rightsType : integer : 权益类型
    params: rightsName : string : 权益名称
    params: orderMainId : string : 主订单ID
    params: userId : number : 用户ID
    params: mobile : string : 用户手机号
    params: payAmount : string : 支付金额
    params: useStatus : integer : 权益使用状态
    params: receiveDate : string : 权益领取时间
    params: payDate : string : 权益支付时间
    params: refundDate : string : 权益退款时间
    params: payBillNo : string : 支付流水
    params: refundBillNo : string : 退款流水
    params: createTime : string : 创建时间
    params: createBy : number : 创建人
    params: updateTime : string : 更新时间
    params: updateId : number : 更新人id
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/order/rightsOrder/insert"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "rightsOrderId": rightsOrderId,  # 权益订单ID
        "rightsId": rightsId,  # 权益ID
        "rightsType": rightsType,  # 权益类型
        "rightsName": rightsName,  # 权益名称
        "orderMainId": orderMainId,  # 主订单ID
        "userId": userId,  # 用户ID
        "mobile": mobile,  # 用户手机号
        "payAmount": payAmount,  # 支付金额
        "useStatus": useStatus,  # 权益使用状态
        "receiveDate": receiveDate,  # 权益领取时间
        "payDate": payDate,  # 权益支付时间
        "refundDate": refundDate,  # 权益退款时间
        "payBillNo": payBillNo,  # 支付流水
        "refundBillNo": refundBillNo,  # 退款流水
        "createTime": createTime,  # 创建时间
        "createBy": createBy,  # 创建人
        "updateTime": updateTime,  # 更新时间
        "updateId": updateId,  # 更新人id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rightsOrder/page")
def order_rightsorder_page(rightsType=None, userId=None, current=None, size=None, receiveDateEnd=None, orderMainId=None, payDateBegin=None, receiveDateBegin=None, mobile=None, payDateEnd=None, rightsOrderId=None, useStatus=None, headers=None, **kwargs):
    """
    权益订单 - 分页查询-Y
    up_time=1675412172

    params: size :  : 
    params: current :  : 
    params: userId :  : 用户ID
    params: mobile :  : 手机号码 
    params: rightsOrderId :  : 权益订单ID
    params: orderMainId :  : 主订单ID
    params: useStatus :  : 权益使用状态
    params: rightsType :  : 权益类型
    params: receiveDateBegin :  : 权益领取时间 开始
    params: receiveDateEnd :  : 权益领取时间-结束
    params: payDateBegin :  : 权益支付时间 - 开始
    params: payDateEnd :  : 权益支付时间 - 结束
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
    """
    _method = "GET"
    _url = "/order/rightsOrder/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "size": size,
        "current": current,
        "userId": userId,  # 用户ID
        "mobile": mobile,  # 手机号码 
        "rightsOrderId": rightsOrderId,  # 权益订单ID
        "orderMainId": orderMainId,  # 主订单ID
        "useStatus": useStatus,  # 权益使用状态
        "rightsType": rightsType,  # 权益类型
        "receiveDateBegin": receiveDateBegin,  # 权益领取时间 开始
        "receiveDateEnd": receiveDateEnd,  # 权益领取时间-结束
        "payDateBegin": payDateBegin,  # 权益支付时间 - 开始
        "payDateEnd": payDateEnd,  # 权益支付时间 - 结束
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rightsOrder/receive")
def order_rightsorder_receive(rightsId=None, orderId=None, headers=None, **kwargs):
    """
    权益-领取权益-Y
    up_time=1675660702

    params: orderId : string : 子订单ID
    params: rightsId : number : 权益ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              orderMainId : string : 主订单ID
              userId : number : 用户ID
              mobile : string : 用户手机号
              rightsOrderId : number : 权益订单ID
              rightsId : string : 权益ID
              rightsType : integer : 权益类型
              rightsName : string : 权益名称
              payAmount : string : 支付金额
              useStatus : string : 权益使用状态
              receiveDate : string : 权益领取时间
              createTime : string : 创建时间
              createBy : number : 创建人
              delFlag : integer : 删除标识 0：否 1：是
              field_160 : string : 用户手机号
    """
    _method = "POST"
    _url = "/order/rightsOrder/receive"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,  # 子订单ID
        "rightsId": rightsId,  # 权益ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rightsOrder/getOrderList")
def order_rightsorder_getorderlist(rightsType=None, receiveDate=None, rightsNameList=None, useStatusList=None, mobile=None, orderMainId=None, headers=None, **kwargs):
    """
    权益订单 - 查询-Y
    up_time=1675413979

    params: orderMainId : number : 主订单ID
    params: rightsType : integer : 权益类型
    params: rightsNameList : array : 权益名称
              type : string : None
    params: useStatusList : array : 权益使用状态
              type : integer : None
    params: mobile : string : 用户手机号
    params: receiveDate : string : 权益领取时间
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              rightsOrderId : number : 权益订单ID
              rightsId : number : 权益ID
              rightsType : integer : 权益类型
              rightsName : string : 权益名称
              rightsInfo : object : 权益信息
              orderMainId : string : 主订单ID
              userId : string : 用户ID
              mobile : string : 用户手机号
              payAmount : string : 支付金额
              useStatus : integer : 权益使用状态 (10未使用、20使用中、30使用成功、40使用失败、50已失效)
              useStatusName : string : 权益使用状态名称
              receiveDate : string : 权益领取时间
              payDate : string : 权益支付时间
              refundDate : string : 权益退款时间
              payBillNo : string : 支付流水
              refundBillNo : string : 退款流水
              createTime : string : 创建时间
              createBy : number : 创建人
              updateTime : string : 更新时间
              updateId : number : 更新人id
    """
    _method = "POST"
    _url = "/order/rightsOrder/getOrderList"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderMainId": orderMainId,  # 主订单ID
        "rightsType": rightsType,  # 权益类型
        "rightsNameList": rightsNameList,  # 权益名称
        "useStatusList": useStatusList,  # 权益使用状态
        "mobile": mobile,  # 用户手机号
        "receiveDate": receiveDate,  # 权益领取时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rightsOrder/statusUpdate")
def order_rightsorder_statusupdate(soNo=None, workStatus=None, headers=None, **kwargs):
    """
    更新充电桩订单状态-Y
    up_time=1675414502

    params: soNo :  : 第三方订单
    params: workStatus :  : 权益使用状态
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败1成功
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "GET"
    _url = "/order/rightsOrder/statusUpdate"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "soNo": soNo,  # 第三方订单
        "workStatus": workStatus,  # 权益使用状态
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/common/getChannel")
def common_common_getchannel( headers=None, **kwargs):
    """
    文章-获取发布渠道-Y
    up_time=1675323365

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              channelId : number : 渠道主键
              channelName : string : 渠道名称
              status : integer : 状态码1：可用0：不可用
              createBy : number : 
              createTime : string : 
              updateBy : number : 
              updateTime : string : 
    """
    _method = "GET"
    _url = "/common/common/getChannel"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.order.sqls_order_mainorder import SqlsOrderMainorder


class AssertsOrderMainorder(SqlsOrderMainorder):
    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_pagelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_pagelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["createEndTime", "sortItems", "createStartTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_download(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_download(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["createEndTime", "orderTypeToSort", "createTimeToSort", "payTimeToSort", "createStartTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_detail(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_detail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_getuserorderstatuslist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_getuserorderstatuslist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_getordertypelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_getordertypelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_getextorderstatuslist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_getextorderstatuslist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_getorderstatuslist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_getorderstatuslist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_vincode(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_vincode(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["vin"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_finish(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_finish(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_allpricecontent(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_allpricecontent(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_getorderidbyuser(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_getorderidbyuser(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder__getmodelnamebyorderid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder__getmodelnamebyorderid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_getcarconfigbyorderid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_getcarconfigbyorderid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_syncscrmextorder(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_syncscrmextorder(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["VIN", "deliveryData", "phone", "ossId", "potentialName", "optionCode", "orderId", "updateTime", "orderAllAmount", "syncMsg", "modelCode", "isArrived", "orderNo", "unitInvoiceTitle", "isTestDrive", "scUname", "syncStatus", "customerCtCode", "dealerCode", "seriesCode", "colorCode", "trimCode", "custCertNo", "isLifetimeWarranty", "createTime", "lifetimeWarrantyPrice", "customerId", "customerType", "soNo", "unitTaxNo", "soStatus", "chargePointEquity", "unitName", "configCode", "scUid"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_mainorder_informorder(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_mainorder_informorder(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["systemCode", "sourceInfo"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.order.asserts_order_testdrive import AssertsOrderTestdrive
from service.app_a.apis.order import apis_order_testdrive


class FunsOrderTestdrive(AssertsOrderTestdrive):
    @allure.step(title="导出试驾表单-Y")
    def order_testdrive_exportlist(self, createByName="$None$", createTime="$None$", shopName="$None$", phoneNumber="$None$", channel="$None$", endTime="$None$", id="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/order/testDrive/exportList
                params: phoneNumber :  : 手机号
                params: createByName :  :
                params: id :  : 主键
                params: channel :  : 渠道(1:移动应用 2:小程序 3:官方网站)
                params: startTime :  :
                params: endTime :  :
                params: shopName :  : 门店名称
                params: createTime :  : 创建时间
                params: headers : 请求头
        """
        createByName = self.get_list_choice(createByName, list_or_dict=None, key="createByName")
        createTime = self.get_list_choice(createTime, list_or_dict=None, key="createTime")
        shopName = self.get_list_choice(shopName, list_or_dict=None, key="shopName")
        phoneNumber = self.get_list_choice(phoneNumber, list_or_dict=None, key="phoneNumber")
        channel = self.get_list_choice(channel, list_or_dict=None, key="channel")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        id = self.get_list_choice(id, list_or_dict=None, key="id")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_testdrive.order_testdrive_exportlist(**_kwargs)

        self.assert_order_testdrive_exportlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户中心-预约信息")
    def order_testdrive_userlist(self, modelId="$None$", size=10, current=1, createBy="$None$", _assert=True,  **kwargs):
        """
            url=/order/testDrive/userList
                params: current :  : 当前页数
                params: size :  : 每页数据数
                params: createBy :  :
                params: modelId :  :
                params: headers : 请求头
        """
        modelId = self.get_list_choice(modelId, list_or_dict=None, key="modelId")
        createBy = self.get_list_choice(createBy, list_or_dict=None, key="createBy")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_testdrive.order_testdrive_userlist(**_kwargs)

        self.assert_order_testdrive_userlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/goods/testDrive/driveExports")
def goods_testdrive_driveexports(exportType=None, shopName=None, userName=None, channel=None, endTime=None, mobile=None, testDriveIdStr=None, startTime=None, headers=None, **kwargs):
    """
    试驾列表文件导出接口-Y
    up_time=1675390810

    params: mobile :  : 手机号
    params: userName :  : 用户名
    params: shopName :  : 店名
    params: channel :  : 渠道
    params: startTime :  : 开始时间
    params: endTime :  : 结束时间
    params: exportType :  : 导出类型
    params: testDriveIdStr :  : 订单集合字符串
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/goods/testDrive/driveExports"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "mobile": mobile,  # 手机号
        "userName": userName,  # 用户名
        "shopName": shopName,  # 店名
        "channel": channel,  # 渠道
        "startTime": startTime,  # 开始时间
        "endTime": endTime,  # 结束时间
        "exportType": exportType,  # 导出类型
        "testDriveIdStr": testDriveIdStr,  # 订单集合字符串
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/testDrive/page")
def goods_testdrive_page(shopName=None, userName=None, pageNum=None, channel=None, endTime=None, pageSize=None, mobile=None, startTime=None, headers=None, **kwargs):
    """
    试驾查询接口-Y
    up_time=1675390631

    params: mobile :  : 手机号
    params: userName :  : 客户名
    params: shopName :  : 店名
    params: channel :  : 渠道
    params: startTime :  : 开始时间
    params: endTime :  : 结束时间
    params: pageNum :  : 当前页数
    params: pageSize :  : 每页数据数
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0-成功；1-失败
    params: msg : string : 信息
    params: data : object : 数据
              records : array : 
              total : string : 总数量
              size : string : 分页大小
              current : string : 当前页码
              pages : string : 总页数
    """
    _method = "GET"
    _url = "/goods/testDrive/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "mobile": mobile,  # 手机号
        "userName": userName,  # 客户名
        "shopName": shopName,  # 店名
        "channel": channel,  # 渠道
        "startTime": startTime,  # 开始时间
        "endTime": endTime,  # 结束时间
        "pageNum": pageNum,  # 当前页数
        "pageSize": pageSize,  # 每页数据数
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.goods.asserts_goods_configure import AssertsGoodsConfigure
from service.app_a.apis.goods import apis_goods_configure


class FunsGoodsConfigure(AssertsGoodsConfigure):
    @allure.step(title="保存车型配置信息-Y")
    def goods_configure_savecarconfigure(self, processColorList="$None$", optionalList="$None$", salesVersionList="$None$", appearanceColorList="$None$", interiorColorList="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/goods/configure/saveCarConfigure
                params: salesVersionList : array : 销售版本
                configureId : string : 配置ID
                modelId : string : 关联的车型基础信息ID
                configureCode : string : 配置编码
                configureName : string : 配置名称
                saleVersion : string : 销售-版本号
                abbreviationList : array : 缩略图
                gwAbbreviationList : array : 官网缩略图
                defaultCarModelList : array : 默认车型
                gwDefaultCarModelList : array : 官网默认车型
                price : number : 零售价|加价
                sort : number : 前台权重
                versionDesc : string : 版本描述
                partsDesc : string : 配件描述
                status : number : 状态 （1:启用，0：禁用） 默认启用
                type : number : 1:销售版本,2:动力系统,3:外观颜色,4:内饰颜色,5:选装配置
                params: processColorList : array : 套色
                configureId : string : 配置ID
                modelId : string : 车型ID
                configureCode : string : 配置编码
                configureName : string : 配置名称
                saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
                appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
                saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
                modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
                abbreviationList : array : 缩略图
                gwAbbreviationList : array : 官网缩略图
                defaultCarModelList : array : 默认车型
                gwDefaultCarModelList : array : 官网默认车型
                price : number : 加价
                sort : number : 排序
                versionDesc : string :
                partsDesc : string :
                status : number : 状态
                type : number : 类型
                params: appearanceColorList : array : 外观颜色
                configureId : string : 配置Id
                modelId : string : 车型ID
                configureCode : string : 配置编码
                configureName : string : 配置名称
                saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
                appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
                saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
                modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
                abbreviationList : array : 缩略图
                gwAbbreviationList : array : 官网缩略图
                defaultCarModelList : array : 默认车型
                gwDefaultCarModelList : array : 官网默认车型
                price : number : 加价
                sort : number : 排序
                versionDesc : string :
                partsDesc : string :
                status : number : 状态
                type : number : 类型
                params: interiorColorList : array : 内饰颜色
                configureId : string : 配置ID
                modelId : string : 车型Id
                configureCode : string : 配置编码
                configureName : string : 配置名称
                saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
                appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
                saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
                modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
                abbreviationList : array : 缩略图
                gwAbbreviationList : array : 官网缩略图
                defaultCarModelList : array : 默认车型
                gwDefaultCarModelList : array : 官网默认车型
                price : number : 加价
                sort : number : 排序
                versionDesc : string :
                partsDesc : string :
                status : number : 状态
                type : number : 类型
                params: optionalList : array : 选装配件
                configureId : string : 配置ID
                modelId : string : 车型ID
                configureCode : string : 配置编码
                configureName : string : 配置名称
                saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
                appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
                saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
                modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
                abbreviationList : array : 缩略图
                gwAbbreviationList : array : 官网缩略图
                defaultCarModelList : array : 默认车型
                gwDefaultCarModelList : array : 官网默认车型
                price : number : 加价
                sort : number : 排序
                versionDesc : string :
                partsDesc : string : 配件描述
                status : number : 状态 默认启用 1
                type : number : 1:销售版本,2:外观颜色,3:套色,4:内饰颜色,5:选装配置
                params: headers : 请求头
        """
        processColorList = self.get_value_choice(processColorList, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        optionalList = self.get_value_choice(optionalList, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        salesVersionList = self.get_value_choice(salesVersionList, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        appearanceColorList = self.get_value_choice(appearanceColorList, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        interiorColorList = self.get_value_choice(interiorColorList, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_configure.goods_configure_savecarconfigure(**_kwargs)

        self.assert_goods_configure_savecarconfigure(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="查询配置名称-Y")
    def goods_configure_getcarconfigurename(self, modelId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/configure/getCarConfigureName
                params: modelId :  : 车型Id
                params: headers : 请求头
        """
        modelId = self.get_list_choice(modelId, list_or_dict=None, key="modelId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_configure.goods_configure_getcarconfigurename(**_kwargs)

        self.assert_goods_configure_getcarconfigurename(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="车型配置删除-D")
    def goods_configure_removecarconfigure(self, configureId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/configure/removeCarConfigure
                params: configureId :  : 主键Id
                params: headers : 请求头
        """
        configureId = self.get_list_choice(configureId, list_or_dict=None, key="configureId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_configure.goods_configure_removecarconfigure(**_kwargs)

        self.assert_goods_configure_removecarconfigure(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="车型配置更改状态-D")
    def goods_configure_updatecarconfigurestatus(self, configureId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/configure/updateCarConfigureStatus
                params: configureId :  : 车型配置Id
                params: headers : 请求头
        """
        configureId = self.get_list_choice(configureId, list_or_dict=None, key="configureId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_configure.goods_configure_updatecarconfigurestatus(**_kwargs)

        self.assert_goods_configure_updatecarconfigurestatus(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="车型配置查询（930）-?")
    def goods_configure_info(self, modelId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/configure/info
                params: modelId :  : 车型基础ID
                params: headers : 请求头
        """
        modelId = self.get_list_choice(modelId, list_or_dict=None, key="modelId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_configure.goods_configure_info(**_kwargs)

        self.assert_goods_configure_info(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/adv/save")
def content_adv_save(jumpContent=None, advPicUrl=None, advText=None, jumpType=None, advId=None, advLinkUrl=None, bindingFlag=None, version=None, advSerial=None, advPlaceId=None, pictureList=None, headers=None, **kwargs):
    """
    点位内容-保存运营端配置(更新、新增)（930）-Y
    up_time=1675674291

    params: advPlaceId : number : 左侧列表选中ID
    params: advPicUrl : string : 图片地址
    params: advText : string : 文字描述
    params: advSerial : string : 排序
    params: jumpType : number : 跳转类型
    params: jumpContent : string : 跳转内容
    params: advId : number : 点位ID（更新时必传）
    params: version : string : 绑定的车系（60s,80v）
    params: advLinkUrl : string : 爱车海报填写地址/url跳转地址
    params: bindingFlag : number : 车辆绑定标识 1绑定 0未绑定
    params: pictureList : array : 当跳转类型为16：图片新增字段
              type : string : None
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 
    params: data : boolean : true成功
    """
    _method = "POST"
    _url = "/content/adv/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "advPlaceId": advPlaceId,  # 左侧列表选中ID
        "advPicUrl": advPicUrl,  # 图片地址
        "advText": advText,  # 文字描述
        "advSerial": advSerial,  # 排序
        "jumpType": jumpType,  # 跳转类型
        "jumpContent": jumpContent,  # 跳转内容
        "advId": advId,  # 点位ID（更新时必传）
        "version": version,  # 绑定的车系（60s,80v）
        "advLinkUrl": advLinkUrl,  # 爱车海报填写地址/url跳转地址
        "bindingFlag": bindingFlag,  # 车辆绑定标识 1绑定 0未绑定
        "pictureList": pictureList,  # 当跳转类型为16：图片新增字段
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/updateEssayAdvList")
def content_adv_updateessayadvlist(essayId=None, headers=None, **kwargs):
    """
    点位内容-修改点位信息-Y
    up_time=1675674872

    params: essayId : string : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/adv/updateEssayAdvList"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/setTopFlag")
def content_adv_settopflag(essayId=None, headers=None, **kwargs):
    """
    点位内容-文章置顶-Y
    up_time=1675673726

    params: essayId : text : 文章主键Id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/adv/setTopFlag"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键Id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/advPlaceList")
def content_adv_advplacelist(advPlaceId=None, headers=None, **kwargs):
    """
    点位内容-点位查询接口-Y
    up_time=1677046697

    params: advPlaceId :  : 广告点位主键：
【发现-推荐】轮播图
【发现-推荐】快捷入口
【发现-资讯】金刚区
【爱车】试驾页轮播
【发现-推荐】精选内容
【爱车-智能车控】
【爱车-购车帮助】
【我的-邀请好友】海报图
【我的-积分】积分规则说明
【爱车-购车帮助（新）】

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/adv/advPlaceList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "advPlaceId": advPlaceId,  # 广告点位主键： 【发现-推荐】轮播图 【发现-推荐】快捷入口 【发现-资讯】金刚区 【爱车】试驾页轮播 【发现-推荐】精选内容 【爱车-智能车控】 【爱车-购车帮助】 【我的-邀请好友】海报图 【我的-积分】积分规则说明 【爱车-购车帮助（新）】 
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/delete")
def content_adv_delete(advId=None, headers=None, **kwargs):
    """
    点位内容-删除-Y
    up_time=1675674198

    params: advId : string : 点位ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : boolean : true成功
    """
    _method = "POST"
    _url = "/content/adv/delete"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "advId": advId,  # 点位ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/detailAdmin")
def content_adv_detailadmin(advPlaceId=None, headers=None, **kwargs):
    """
    点位查询(930版本)-Y
    up_time=1675672243

    params: advPlaceId :  : 广告位id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 数据
              advPlaceId : string : 点位D
              advPlaceName : string : 点位名称
              advPlaceType : number : 广告位类型 1：焦点图类型点位 2、导航类型点位 
              createTime : string : 
              createBy : string : 
              updateTime : string : 
              updateBy : string : 
              obj : null : 
              adv : null : 
              advList : array : 点位内容
    """
    _method = "GET"
    _url = "/content/adv/detailAdmin"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "advPlaceId": advPlaceId,  # 广告位id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/saveAll")
def content_adv_saveall(jumpType=None, advPlaceId=None, headers=None, **kwargs):
    """
    点位内容-新增广告位（点位）-Y
    up_time=1675674158

    params: advPlaceId : number : 广告位ID
    params: jumpType : integer : 备注中查看状态信息
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/adv/saveAll"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "advPlaceId": advPlaceId,  # 广告位ID
        "jumpType": jumpType,  # 备注中查看状态信息
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/jumpContent")
def content_adv_jumpcontent(typeCode=None, keyWord=None, headers=None, **kwargs):
    """
    点位内容-根据跳转类型选择跳转内容（930）-Y
    up_time=1675674398

    params: typeCode :  : 跳转类型
    params: keyWord :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0正常
    params: msg : string : 描述
    params: data : array : 返回数据
              contentName : string : 跳转名称
              jumpContent : string : 跳转内容
              jumpType : number : 跳转类型
    """
    _method = "GET"
    _url = "/content/adv/jumpContent"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "typeCode": typeCode,  # 跳转类型
        "keyWord": keyWord,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/detailConTentAdmin")
def content_adv_detailcontentadmin(size=None, current=None, orderByCommentCnt=None, essayKeyWords=None, headers=None, **kwargs):
    """
    点位内容-查询推荐页内容-Y
    up_time=1675673291

    params: current :  : 
    params: size :  : 
    params: essayKeyWords :  : 
    params: orderByCommentCnt :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : string : 
              size : string : 
              current : string : 
    """
    _method = "GET"
    _url = "/content/adv/detailConTentAdmin"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "essayKeyWords": essayKeyWords,
        "orderByCommentCnt": orderByCommentCnt,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/jumpTypeList")
def content_adv_jumptypelist( headers=None, **kwargs):
    """
    点位内容-查询跳转类型-Y
    up_time=1675674356

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : array : 
              typeName : string : 跳转类型名称
              typeCode : string : 跳转类型编码
    """
    _method = "GET"
    _url = "/content/adv/jumpTypeList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/cancelRecommend")
def content_adv_cancelrecommend(essayId=None, headers=None, **kwargs):
    """
    点位内容-取消推荐-Y
    up_time=1675673822

    params: essayId : string : 文章主键Id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/content/adv/cancelRecommend"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键Id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/adv/detail")
def content_adv_detail(advPlaceId=None, headers=None, **kwargs):
    """
    点位-根据点位主键查询点位信息(930版本)
    up_time=1676685657

    params: advPlaceId :  : 广告点位主键 
 1:[发现-推荐]轮播图
 2:[发现-推荐]快捷入口
 5:[发现-资讯]金刚区
 6:[爱车]试驾页轮播
 8:[发现-推荐]精选内容
 9:[爱车-智能车控]
 10:[爱车-购车帮助]
 11:[我的-邀请好友]海报图
 12:[我的-积分]积分规则明细

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : object : 
    """
    _method = "GET"
    _url = "/content/adv/detail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "advPlaceId": advPlaceId,  # 广告点位主键   1:[发现-推荐]轮播图  2:[发现-推荐]快捷入口  5:[发现-资讯]金刚区  6:[爱车]试驾页轮播  8:[发现-推荐]精选内容  9:[爱车-智能车控]  10:[爱车-购车帮助]  11:[我的-邀请好友]海报图  12:[我的-积分]积分规则明细 
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.order.rights.sqls_order_rights_rightsmanager import SqlsOrderRightsRightsmanager


class AssertsOrderRightsRightsmanager(SqlsOrderRightsRightsmanager):
    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_createid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_createid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_getrelation(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_getrelation(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsName", "modelCode", "effectiveEndDate", "status"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_getrightslist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_getrightslist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsName", "effectiveStartDate", "modelId", "status"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsId", "modelCode", "rightsName", "rightsType", "orderType", "effectiveStartDate"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsName", "rightsId", "Content", "effectiveStartDate", "effectiveEndDate", "Relation"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_rightsbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_rightsbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_rights_rightsmanager_updatestatusbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rights_rightsmanager_updatestatusbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsId", "status"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/hotSearch/rank")
def content_hotsearch_rank(kId=None, rank=None, headers=None, **kwargs):
    """
    热门搜索-修改权重-Y
    up_time=1675737497

    params: kId : string : 主键id
    params: rank : string : 权重
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1失败
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/hotSearch/rank"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "kId": kId,  # 主键id
        "rank": rank,  # 权重
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/hotSearch/list")
def content_hotsearch_list(kId=None, rank=None, headers=None, **kwargs):
    """
    热门搜索-列表-Y
    up_time=1675737340

    params: kId : string : 主键id
    params: rank : string : 权重
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/hotSearch/list"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "kId": kId,  # 主键id
        "rank": rank,  # 权重
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/hotSearch/insert")
def content_hotsearch_insert(keyWord=None, point=None, headers=None, **kwargs):
    """
    热门搜索-新增-Y
    up_time=1675737410

    params: keyWord : string : 关键词(城市名)
    params: point : string : 1 发现-搜索 4 活动定位
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功  1 失败
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/hotSearch/insert"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "keyWord": keyWord,  # 关键词(城市名)
        "point": point,  # 1 发现-搜索 4 活动定位
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.radarpoints.userpoints.asserts_radarpoints_userpoints_exchangeinfo import AssertsRadarpointsUserpointsExchangeinfo
from service.app_a.apis.radarpoints.userpoints import apis_radarpoints_userpoints_exchangeinfo


class FunsRadarpointsUserpointsExchangeinfo(AssertsRadarpointsUserpointsExchangeinfo):
    @allure.step(title="用户中心-兑换明细 - 分页查询")
    def radarpoints_userpoints_exchangeinfo_pagelist(self, consigneeName="$None$", userId="$None$", size=10, orderStartTime="$None$", mobile="$None$", orderEndTime="$None$", goodsOrderId="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/radarpoints/userPoints/exchangeInfo/pageList
                params: size :  : 每页大小
                params: current :  : 当前页
                params: consigneeName :  : 收货人姓名
                params: goodsOrderId :  : 商品订单
                params: mobile :  : 收货人电话
                params: orderStartTime :  : 下单开始时间
                params: orderEndTime :  : 下单结束时间
                params: headers : 请求头
        """
        consigneeName = self.get_list_choice(consigneeName, list_or_dict=None, key="consigneeName")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        orderStartTime = self.get_list_choice(orderStartTime, list_or_dict=None, key="orderStartTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        orderEndTime = self.get_list_choice(orderEndTime, list_or_dict=None, key="orderEndTime")
        goodsOrderId = self.get_list_choice(goodsOrderId, list_or_dict=None, key="goodsOrderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_userpoints_exchangeinfo.radarpoints_userpoints_exchangeinfo_pagelist(**_kwargs)

        self.assert_radarpoints_userpoints_exchangeinfo_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





from service.app_a.funs.radarpoints.funs_radarpoints_pointstask import FunsRadarpointsPointstask
from service.app_a.funs.radarpoints.funs_radarpoints_pointsconfig import FunsRadarpointsPointsconfig
from service.app_a.funs.radarpoints.funs_radarpoints_userpoints import FunsRadarpointsUserpoints
from service.app_a.funs.radarpoints.funs_radarpoints_summarystatistics import FunsRadarpointsSummarystatistics
from service.app_a.funs.radarpoints.funs_radarpoints_adjustpoints import FunsRadarpointsAdjustpoints


class FunsRadarpoints(FunsRadarpointsPointstask, FunsRadarpointsPointsconfig, FunsRadarpointsUserpoints, FunsRadarpointsSummarystatistics, FunsRadarpointsAdjustpoints):
    pass




import allure

from service.app_a.asserts.content.asserts_content_essaycomment import AssertsContentEssaycomment
from service.app_a.apis.content import apis_content_essaycomment


class FunsContentEssaycomment(AssertsContentEssaycomment):
    @allure.step(title="后台管理-新建评论/回复1030-Y")
    def content_essaycomment_manageadd(self, author="$None$", content="$None$", essayId="$None$", parentId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/essaycomment/manageAdd
                params: essayId : string : 文章id
                params: author : string : 评论人id
                params: content : string : 内容
                params: parentId : string : 所回复评论的id 新建评论不用传 回复要传
                params: headers : 请求头
        """
        author = self.get_value_choice(author, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        parentId = self.get_value_choice(parentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essaycomment.content_essaycomment_manageadd(**_kwargs)

        self.assert_content_essaycomment_manageadd(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.asserts_testdrive import AssertsTestdrive
from service.app_a.apis import apis_testdrive


class FunsTestdrive(AssertsTestdrive):
    @allure.step(title="预约试驾")
    def testdrive_subscribe(self, appointmentTime="$None$", shopName="$None$", phoneNumber="$None$", channel="$None$", leadSourceCode="$None$", model="$None$", shopId="$None$", activityCode="$None$", customerName="$None$", modelId="$None$", leadSanSourceCode="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/testDrive/subscribe
                params: model : text : 试驾车型名称
                params: shopName : text : 门店名称
                params: customerName : text : 客户姓名、昵称
                params: phoneNumber : text : 预留手机号
                params: channel : text : 1:移动应用 2:小程序 3:官方网站
                params: modelId : text : 预约车型id
                params: shopId : text : 预约门店id
                params: appointmentTime : text : 预约时间
                params: activityCode : string : 活动代码
                params: leadSourceCode : string : 线索来源小类
                params: leadSanSourceCode : string : 线索来源三级小类
                params: headers : 请求头
        """
        appointmentTime = self.get_value_choice(appointmentTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        shopName = self.get_value_choice(shopName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        phoneNumber = self.get_value_choice(phoneNumber, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        channel = self.get_value_choice(channel, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        leadSourceCode = self.get_value_choice(leadSourceCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        model = self.get_value_choice(model, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        shopId = self.get_value_choice(shopId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityCode = self.get_value_choice(activityCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        customerName = self.get_value_choice(customerName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelId = self.get_value_choice(modelId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        leadSanSourceCode = self.get_value_choice(leadSanSourceCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_testdrive.testdrive_subscribe(**_kwargs)

        self.assert_testdrive_subscribe(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.radarpoints.asserts_radarpoints_pointsconfig import AssertsRadarpointsPointsconfig
from service.app_a.apis.radarpoints import apis_radarpoints_pointsconfig


class FunsRadarpointsPointsconfig(AssertsRadarpointsPointsconfig):
    @allure.step(title="积分配置 - 分页查询")
    def radarpoints_pointsconfig_page(self, code="$None$", pointsBegin="$None$", size=10, name="$None$", pointsExpiration="$None$", Current="$None$", pointsEnd="$None$", status="$None$", businessSceneType="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/PointsConfig/page
                params: code :  : 积分项Code
                params: name :  : 积分项名称
                params: businessSceneType :  : 发放场景类型
                params: pointsBegin :  : 积分值 - 开始区间
                params: pointsEnd :  : 积分值 - 结束区间
                params: pointsExpiration :  : 积分有效期
                params: status :  : 生效状态（0未生效，1已生效）
                params: Current :  : 当前页
                params: size :  : 每页大小
                params: headers : 请求头
        """
        code = self.get_list_choice(code, list_or_dict=None, key="code")
        pointsBegin = self.get_list_choice(pointsBegin, list_or_dict=None, key="pointsBegin")
        name = self.get_list_choice(name, list_or_dict=None, key="name")
        pointsExpiration = self.get_list_choice(pointsExpiration, list_or_dict=None, key="pointsExpiration")
        Current = self.get_list_choice(Current, list_or_dict=None, key="Current")
        pointsEnd = self.get_list_choice(pointsEnd, list_or_dict=None, key="pointsEnd")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        businessSceneType = self.get_list_choice(businessSceneType, list_or_dict=None, key="businessSceneType")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_pointsconfig.radarpoints_pointsconfig_page(**_kwargs)

        self.assert_radarpoints_pointsconfig_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分配置 -新增积分配置")
    def radarpoints_pointsconfig_insert(self, remark="$None$", name="$None$", points="$None$", rulesPointsDayMax="$None$", pointsExpiration="$None$", bpmId="$None$", userPointsDayMax="$None$", toast="$None$", businessSceneType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/radarpoints/PointsConfig/insert
                params: pointsExpiration : string : 积分有效期
                params: remark : string : 备注
                params: points : integer : 积分值
                params: toast : string : toast内容
                params: name : string : 积分项名称
                params: businessSceneType : integer : 发放场景类型
                params: bpmId : integer : bpm单号
                params: userPointsDayMax : integer : 单用户单日上限
                params: rulesPointsDayMax : integer : 单日上限
                params: headers : 请求头
        """
        remark = self.get_value_choice(remark, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        name = self.get_value_choice(name, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        points = self.get_value_choice(points, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rulesPointsDayMax = self.get_value_choice(rulesPointsDayMax, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        pointsExpiration = self.get_value_choice(pointsExpiration, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        bpmId = self.get_value_choice(bpmId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        userPointsDayMax = self.get_value_choice(userPointsDayMax, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        toast = self.get_value_choice(toast, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        businessSceneType = self.get_value_choice(businessSceneType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_pointsconfig.radarpoints_pointsconfig_insert(**_kwargs)

        self.assert_radarpoints_pointsconfig_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分配置 -修改积分配置")
    def radarpoints_pointsconfig_update(self, remark="$None$", code="$None$", name="$None$", points="$None$", rulesPointsDayMax="$None$", pointsExpiration="$None$", userPointsDayMax="$None$", bpmId="$None$", id="$None$", toast="$None$", businessSceneType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/radarpoints/PointsConfig/update
                params: pointsExpiration : string : 积分有效期
                params: remark : string : 备注
                params: points : integer : 积分值
                params: toast : string : toast内容
                params: name : string : 积分项名称
                params: businessSceneType : integer : 发放场景类型
                params: id : integer : 积分项id
                params: code : string : 积分项code
                params: rulesPointsDayMax : integer : 单日上限
                params: userPointsDayMax : integer : 单用户单日上限
                params: bpmId : integer : bpm单号
                params: headers : 请求头
        """
        remark = self.get_value_choice(remark, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        code = self.get_value_choice(code, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        name = self.get_value_choice(name, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        points = self.get_value_choice(points, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rulesPointsDayMax = self.get_value_choice(rulesPointsDayMax, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        pointsExpiration = self.get_value_choice(pointsExpiration, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        userPointsDayMax = self.get_value_choice(userPointsDayMax, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        bpmId = self.get_value_choice(bpmId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        id = self.get_value_choice(id, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        toast = self.get_value_choice(toast, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        businessSceneType = self.get_value_choice(businessSceneType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_pointsconfig.radarpoints_pointsconfig_update(**_kwargs)

        self.assert_radarpoints_pointsconfig_update(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分配置 -生效状态变更")
    def radarpoints_pointsconfig_updatestatusbyid(self, id="$None$", status="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/PointsConfig/updateStatusById
                params: id :  : 积分id
                params: status :  : 生效状态（0未生效，1已生效）
                params: headers : 请求头
        """
        id = self.get_list_choice(id, list_or_dict=None, key="id")
        status = self.get_list_choice(status, list_or_dict=None, key="status")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_pointsconfig.radarpoints_pointsconfig_updatestatusbyid(**_kwargs)

        self.assert_radarpoints_pointsconfig_updatestatusbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_messagemanager import AssertsContentMessagemanager
from service.app_a.apis.content import apis_content_messagemanager


class FunsContentMessagemanager(AssertsContentMessagemanager):
    @allure.step(title="消息列表查询接口-Y")
    def content_messagemanager_page(self, pStartTime="$None$", userId="$None$", cStartTime="$None$", authId="$None$", endTime="$None$", messageId="$None$", pEndTime="$None$", cEndTime="$None$", content="$None$", status="$None$", beginTime="$None$", _assert=True,  **kwargs):
        """
            url=/content/messageManager/page
                params: messageId :  :
                params: content :  :
                params: beginTime :  : 前端日期后面必须要追加 00:00:00
                params: endTime :  : 前端日期后面必须要追加 23:59:59
                params: authId :  :
                params: status :  : -1.结束 0.待审核 1.审核通过 2.审核未通过 3.草稿  4.未发布 5.已发布 6.已撤销 7.已归档
                params: pStartTime :  :
                params: pEndTime :  :
                params: cStartTime :  :
                params: cEndTime :  :
                params: headers : 请求头
        """
        pStartTime = self.get_list_choice(pStartTime, list_or_dict=None, key="pStartTime")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        cStartTime = self.get_list_choice(cStartTime, list_or_dict=None, key="cStartTime")
        authId = self.get_list_choice(authId, list_or_dict=None, key="authId")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        messageId = self.get_list_choice(messageId, list_or_dict=None, key="messageId")
        pEndTime = self.get_list_choice(pEndTime, list_or_dict=None, key="pEndTime")
        cEndTime = self.get_list_choice(cEndTime, list_or_dict=None, key="cEndTime")
        content = self.get_list_choice(content, list_or_dict=None, key="content")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        beginTime = self.get_list_choice(beginTime, list_or_dict=None, key="beginTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_page(**_kwargs)

        self.assert_content_messagemanager_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="获取消息详情-Y")
    def content_messagemanager_getmessageinfo_(self, messageId="$None$", _assert=True,  **kwargs):
        """
            url=/content/messageManager/getMessageInfo/{messageId}
                params: messageId :  :
                params: headers : 请求头
        """
        messageId = self.get_list_choice(messageId, list_or_dict=None, key="messageId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_getmessageinfo_(**_kwargs)

        self.assert_content_messagemanager_getmessageinfo_(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="消息置顶/取消置顶-Y")
    def content_messagemanager_messagetop(self, topFlag="$None$", messageIds="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/messageManager/messageTop
                params: messageIds : text : 消息ids集合
                params: topFlag : text : 消息置顶标识 0-置顶 1-不置顶
                params: headers : 请求头
        """
        topFlag = self.get_value_choice(topFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        messageIds = self.get_value_choice(messageIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_messagetop(**_kwargs)

        self.assert_content_messagemanager_messagetop(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="消息新增接口-Y")
    def content_messagemanager_insert(self, imageUrl="$None$", sendScope="$None$", messageId="$None$", param="$None$", checkPublish="$None$", sourceType="$None$", publishType="$None$", checkStatus="$None$", content="$None$", publishTime="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/messageManager/insert
                params: messageId : text :
                params: type : text : 此处传1
                params: content : text :
                params: imageUrl : text :
                params: sourceType : text : 此处传1
                params: param : text :
                params: sendScope : text :
                params: checkStatus : text :
                params: checkPublish : text :
                params: publishType : text :
                params: publishTime : text :
                params: headers : 请求头
        """
        imageUrl = self.get_value_choice(imageUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sendScope = self.get_value_choice(sendScope, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        messageId = self.get_value_choice(messageId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        param = self.get_value_choice(param, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        checkPublish = self.get_value_choice(checkPublish, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sourceType = self.get_value_choice(sourceType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishType = self.get_value_choice(publishType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        checkStatus = self.get_value_choice(checkStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishTime = self.get_value_choice(publishTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_insert(**_kwargs)

        self.assert_content_messagemanager_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="消息编辑接口-Y")
    def content_messagemanager_update(self, imageUrl="$None$", sendScope="$None$", userMobiles="$None$", messageId="$None$", param="$None$", checkPublish="$None$", sourceType="$None$", checkStatus="$None$", content="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/messageManager/update
                params: messageId :  :
                params: type :  : 此处传1
                params: content :  :
                params: imageUrl :  :
                params: sourceType :  : 此处传1
                params: param :  :
                params: sendScope :  :
                params: checkStatus :  :
                params: checkPublish :  :
                params: userMobiles :  : ["131xxxx1234","132xxxx1234"]
                params: headers : 请求头
        """
        imageUrl = self.get_value_choice(imageUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sendScope = self.get_value_choice(sendScope, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        userMobiles = self.get_value_choice(userMobiles, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        messageId = self.get_value_choice(messageId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        param = self.get_value_choice(param, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        checkPublish = self.get_value_choice(checkPublish, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sourceType = self.get_value_choice(sourceType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        checkStatus = self.get_value_choice(checkStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_update(**_kwargs)

        self.assert_content_messagemanager_update(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="消息发布状态修改-Y")
    def content_messagemanager_publishupdate(self, publishStatus="$None$", messageIds="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/messageManager/publishUpdate
                params: messageIds : text :
                params: publishStatus : text :
                params: headers : 请求头
        """
        publishStatus = self.get_value_choice(publishStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        messageIds = self.get_value_choice(messageIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_publishupdate(**_kwargs)

        self.assert_content_messagemanager_publishupdate(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="消息审核状态修改")
    def content_messagemanager_statusupdate(self, checkStatus="$None$", messageIds="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/messageManager/statusUpdate
                params: messageIds : text :
                params: checkStatus : text :
                params: headers : 请求头
        """
        checkStatus = self.get_value_choice(checkStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        messageIds = self.get_value_choice(messageIds, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_messagemanager.content_messagemanager_statusupdate(**_kwargs)

        self.assert_content_messagemanager_statusupdate(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/messageManager/page")
def content_messagemanager_page(pStartTime=None, userId=None, cStartTime=None, authId=None, endTime=None, messageId=None, pEndTime=None, cEndTime=None, content=None, status=None, beginTime=None, headers=None, **kwargs):
    """
    消息列表查询接口-Y
    up_time=1675651897

    params: messageId :  : 
    params: userId :  : 
    params: content :  : 
    params: beginTime :  : 前端日期后面必须要追加 00:00:00
    params: endTime :  : 前端日期后面必须要追加 23:59:59
    params: authId :  : 
    params: status :  : -1.结束 0.待审核 1.审核通过 2.审核未通过 3.草稿  4.未发布 5.已发布 6.已撤销 7.已归档 
    params: pStartTime :  : 
    params: pEndTime :  : 
    params: cStartTime :  : 
    params: cEndTime :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : array : 
              total : number : 总数量
              size : number : 页码大小
              current : number : 当前页码
              pages : number : 总页数
    """
    _method = "GET"
    _url = "/content/messageManager/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "messageId": messageId,
        "userId": userId,
        "content": content,
        "beginTime": beginTime,  # 前端日期后面必须要追加 00:00:00
        "endTime": endTime,  # 前端日期后面必须要追加 23:59:59
        "authId": authId,
        "status": status,  # -1.结束 0.待审核 1.审核通过 2.审核未通过 3.草稿  4.未发布 5.已发布 6.已撤销 7.已归档 
        "pStartTime": pStartTime,
        "pEndTime": pEndTime,
        "cStartTime": cStartTime,
        "cEndTime": cEndTime,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/messageManager/getMessageInfo/")
def content_messagemanager_getmessageinfo_(messageId=None, headers=None, **kwargs):
    """
    获取消息详情-Y
    up_time=1675652084

    params: messageId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              activityId : string : 活动主键
              createTime : string : 创建时间
              createBy : string : 创建人（发布者/作者）
              createByName : string : 创建人（发布者/作者）
              mobile : string : 手机号
              avatar : string : 头像
              username : string : 用户名称
              userType : string : 用户类型 1:内部用户 2:虚拟用户
              activityPicUrl : string : 活动封面图
              title : string : 标题
              joinCnt : string : 参加数量
              activityJoinList : array : 活动参与人数数据集合
    """
    _method = "GET"
    _url = "/content/messageManager/getMessageInfo/{messageId}"
    _url = get_url(_url, locals())

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
        "messageId": messageId,
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/messageManager/messageTop")
def content_messagemanager_messagetop(topFlag=None, messageIds=None, headers=None, **kwargs):
    """
    消息置顶/取消置顶-Y
    up_time=1675652320

    params: messageIds : text : 消息ids集合
    params: topFlag : text : 消息置顶标识 0-置顶 1-不置顶
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/messageManager/messageTop"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "messageIds": messageIds,  # 消息ids集合
        "topFlag": topFlag,  # 消息置顶标识 0-置顶 1-不置顶
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/messageManager/insert")
def content_messagemanager_insert(imageUrl=None, sendScope=None, messageId=None, param=None, checkPublish=None, sourceType=None, publishType=None, checkStatus=None, content=None, publishTime=None, type=None, headers=None, **kwargs):
    """
    消息新增接口-Y
    up_time=1675652341

    params: messageId : text : 
    params: type : text : 此处传1
    params: content : text : 
    params: imageUrl : text : 
    params: sourceType : text : 此处传1
    params: param : text : 
    params: sendScope : text : 
    params: checkStatus : text : 
    params: checkPublish : text : 
    params: publishType : text : 
    params: publishTime : text : 
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/content/messageManager/insert"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "messageId": messageId,
        "type": type,  # 此处传1
        "content": content,
        "imageUrl": imageUrl,
        "sourceType": sourceType,  # 此处传1
        "param": param,
        "sendScope": sendScope,
        "checkStatus": checkStatus,
        "checkPublish": checkPublish,
        "publishType": publishType,
        "publishTime": publishTime,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/messageManager/update")
def content_messagemanager_update(imageUrl=None, sendScope=None, userMobiles=None, messageId=None, param=None, checkPublish=None, sourceType=None, checkStatus=None, content=None, type=None, headers=None, **kwargs):
    """
    消息编辑接口-Y
    up_time=1675652502

    params: messageId :  : 
    params: type :  : 此处传1
    params: content :  : 
    params: imageUrl :  : 
    params: sourceType :  : 此处传1
    params: param :  : 
    params: sendScope :  : 
    params: checkStatus :  : 
    params: checkPublish :  : 
    params: userMobiles :  : ["131xxxx1234","132xxxx1234"]
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/content/messageManager/update"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "messageId": messageId,
        "type": type,  # 此处传1
        "content": content,
        "imageUrl": imageUrl,
        "sourceType": sourceType,  # 此处传1
        "param": param,
        "sendScope": sendScope,
        "checkStatus": checkStatus,
        "checkPublish": checkPublish,
        "userMobiles": userMobiles,  # ["131xxxx1234","132xxxx1234"]
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/messageManager/publishUpdate")
def content_messagemanager_publishupdate(publishStatus=None, messageIds=None, headers=None, **kwargs):
    """
    消息发布状态修改-Y
    up_time=1675652643

    params: messageIds : text : 
    params: publishStatus : text : 
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/content/messageManager/publishUpdate"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "messageIds": messageIds,
        "publishStatus": publishStatus,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/messageManager/statusUpdate")
def content_messagemanager_statusupdate(checkStatus=None, messageIds=None, headers=None, **kwargs):
    """
    消息审核状态修改
    up_time=1675133819

    params: messageIds : text : 
    params: checkStatus : text : 
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/content/messageManager/statusUpdate"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "messageIds": messageIds,
        "checkStatus": checkStatus,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/userPoints/pageList")
def radarpoints_userpoints_pagelist(cumulativeConsumptionMost=None, userId=None, physicalIntegralLeast=None, registrationTimeEnd=None, freezeQtyLeast=None, current=None, registrationTimeBegin=None, size=None, cumulativeAcquisitionMost=None, mobile=None, cumulativeAcquisitionLeast=None, cumulativeConsumptionLeast=None, freezeQtyMost=None, physicalIntegralMost=None, nickName=None, conversionFrequencyLeast=None, conversionFrequencyMost=None, headers=None, **kwargs):
    """
    用户积分 - 分页查询
    up_time=1677209132

    params: userId :  : 用户id
    params: mobile :  : 用户手机号
    params: nickName :  : 用户昵称
    params: registrationTimeBegin :  : 注册时间 - 开始
    params: registrationTimeEnd :  : 注册时间 - 结束
    params: physicalIntegralLeast :  : 持有积分 - 最少
    params: physicalIntegralMost :  : 持有积分 - 最多
    params: cumulativeAcquisitionLeast :  : 累计获取 - 最少
    params: cumulativeAcquisitionMost :  : 累计获取 - 最多
    params: cumulativeConsumptionLeast :  : 累计消耗 - 最少
    params: cumulativeConsumptionMost :  : 累计消耗 - 最多
    params: conversionFrequencyLeast :  : 兑换次数 - 最少
    params: conversionFrequencyMost :  : 兑换次数 - 最多
    params: freezeQtyLeast :  : 冻结积分 - 最少
    params: freezeQtyMost :  : 冻结积分 - 最多
    params: current :  : 页码
    params: size :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200：成功，其他：失败
    params: msg : string : 备注
    params: data : object : 数据
              current : number : 页码
              pages : number : 总页数
              size : number : 每页大小
              total : number : 数据总数
              records : array : list
    """
    _method = "GET"
    _url = "/radarpoints/userPoints/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户id
        "mobile": mobile,  # 用户手机号
        "nickName": nickName,  # 用户昵称
        "registrationTimeBegin": registrationTimeBegin,  # 注册时间 - 开始
        "registrationTimeEnd": registrationTimeEnd,  # 注册时间 - 结束
        "physicalIntegralLeast": physicalIntegralLeast,  # 持有积分 - 最少
        "physicalIntegralMost": physicalIntegralMost,  # 持有积分 - 最多
        "cumulativeAcquisitionLeast": cumulativeAcquisitionLeast,  # 累计获取 - 最少
        "cumulativeAcquisitionMost": cumulativeAcquisitionMost,  # 累计获取 - 最多
        "cumulativeConsumptionLeast": cumulativeConsumptionLeast,  # 累计消耗 - 最少
        "cumulativeConsumptionMost": cumulativeConsumptionMost,  # 累计消耗 - 最多
        "conversionFrequencyLeast": conversionFrequencyLeast,  # 兑换次数 - 最少
        "conversionFrequencyMost": conversionFrequencyMost,  # 兑换次数 - 最多
        "freezeQtyLeast": freezeQtyLeast,  # 冻结积分 - 最少
        "freezeQtyMost": freezeQtyMost,  # 冻结积分 - 最多
        "current": current,  # 页码
        "size": size,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/userPoints/export")
def radarpoints_userpoints_export(cumulativeConsumptionMost=None, physicalIntegralLeast=None, registrationTimeEnd=None, currentPage=None, registrationTimeBegin=None, cumulativeAcquisitionMost=None, pageSize=None, cumulativeAcquisitionLeast=None, cumulativeConsumptionLeast=None, physicalIntegralMost=None, nickName=None, conversionFrequencyLeast=None, conversionFrequencyMost=None, headers=None, **kwargs):
    """
    用户积分 - 导出excel
    up_time=1677216441

    params: nickName :  : 用户昵称
    params: registrationTimeBegin :  : 注册时间 - 开始
    params: registrationTimeEnd :  : 注册时间 - 结束
    params: physicalIntegralLeast :  : 持有积分 - 最少
    params: physicalIntegralMost :  : 持有积分 - 最多
    params: cumulativeAcquisitionLeast :  : 累计获取 - 最少
    params: cumulativeAcquisitionMost :  : 累计获取 - 最多
    params: cumulativeConsumptionLeast :  : 累计消耗 - 最少
    params: cumulativeConsumptionMost :  : 累计消耗 - 最多
    params: conversionFrequencyLeast :  : 兑换次数 - 最少
    params: conversionFrequencyMost :  : 兑换次数 - 最多
    params: currentPage :  : 当前页码
    params: pageSize :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/radarpoints/userPoints/export"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "nickName": nickName,  # 用户昵称
        "registrationTimeBegin": registrationTimeBegin,  # 注册时间 - 开始
        "registrationTimeEnd": registrationTimeEnd,  # 注册时间 - 结束
        "physicalIntegralLeast": physicalIntegralLeast,  # 持有积分 - 最少
        "physicalIntegralMost": physicalIntegralMost,  # 持有积分 - 最多
        "cumulativeAcquisitionLeast": cumulativeAcquisitionLeast,  # 累计获取 - 最少
        "cumulativeAcquisitionMost": cumulativeAcquisitionMost,  # 累计获取 - 最多
        "cumulativeConsumptionLeast": cumulativeConsumptionLeast,  # 累计消耗 - 最少
        "cumulativeConsumptionMost": cumulativeConsumptionMost,  # 累计消耗 - 最多
        "conversionFrequencyLeast": conversionFrequencyLeast,  # 兑换次数 - 最少
        "conversionFrequencyMost": conversionFrequencyMost,  # 兑换次数 - 最多
        "currentPage": currentPage,  # 当前页码
        "pageSize": pageSize,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/order/orderDetail")
def order_order_orderdetail(userId=None, orderStatus=None, pageNum=None, total=None, pageSize=None, orderId=None, headers=None, **kwargs):
    """
    订单详情
    up_time=1675133817

    params: orderId :  : 订单主单Id
    params: userId :  : 用户ID
    params: orderStatus : string : 订单状态
    params: pageSize : number : 每页大小
    params: pageNum : number : 当前页
    params: total : number : 总数
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              orderId : string : 订单主单ID
              orderStatus : string : 
              orderStatusName : string : 
              createTime : string : 
              userName : string : 下单人名称
              mobile : string : 
              prePrice : string : 定金
              totalPrice : string : 总价
              model : object : 
              battery : object : 
              modelPic : object : 
              shopVo : object : 
              itemList : array : 
              areaName : string : 上牌城市
              price : number : 
              pageNum : number : 
              total : number : 
    """
    _method = "GET"
    _url = "/order/order/orderDetail{orderId}{userId}"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,  # 订单主单ID
        "orderStatus": orderStatus,  # 订单状态
        "pageSize": pageSize,  # 每页大小
        "pageNum": pageNum,  # 当前页
        "total": total,  # 总数
    }

    _params = {
        "orderId": orderId,  # 订单主单Id
        "userId": userId,  # 用户ID
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/order/finish")
def order_order_finish(orderId=None, headers=None, **kwargs):
    """
    订单提车-Y
    up_time=1675752665

    params: orderId : string : 主订单ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0.失败 1.成功
    params: msg : string : 
    params: data : object : 
    """
    _method = "POST"
    _url = "/order/order/finish"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,  # 主订单ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/order/refundReject")
def order_order_refundreject(orderId=None, headers=None, **kwargs):
    """
    订单退款驳回-Y
    up_time=1675395220

    params: orderId : string : 主订单ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0.失败 1.成功
    params: msg : string : 
    params: data : object : 
    """
    _method = "POST"
    _url = "/order/order/refundReject"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,  # 主订单ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/mainOrder/scrm2app/refundAuditNotice")
def order_mainorder_scrm2app_refundauditnotice(status=None, orderSubId=None, orderMainId=None, headers=None, **kwargs):
    """
    订单管理-订单退款-Y
    up_time=1675660605

    params: orderMainId : string : 
    params: orderSubId : string : 
    params: status : integer : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败 1成功
    params: msg : string : 
    params: data : object : 
    """
    _method = "POST"
    _url = "/order/mainOrder/scrm2app/refundAuditNotice"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "orderMainId": orderMainId,
        "orderSubId": orderSubId,
        "status": status,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/advplace/updateName")
def content_advplace_updatename(startFlag=None, playTime=None, advPlaceId=None, advPlaceName=None, headers=None, **kwargs):
    """
    点位-更新大点位内容
    up_time=1675133826

    params: advPlaceId : text : 
    params: advPlaceName : text : 
    params: startFlag : text : 广告页广告位必传
    params: playTime : text : 广告页广告位必传
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/content/advplace/updateName"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "advPlaceId": advPlaceId,
        "advPlaceName": advPlaceName,
        "startFlag": startFlag,  # 广告页广告位必传
        "playTime": playTime,  # 广告页广告位必传
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_subject import SqlsContentSubject


class AssertsContentSubject(SqlsContentSubject):
    @allure.step(title="接口返回结果校验")
    def assert_content_subject_detailessay(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_detailessay(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "subjectName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["level", "parentId", "subPicUrl", "explain", "subjectName", "status", "type"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_del(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_del(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_mobilesubject(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_mobilesubject(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "serial", "parentId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_getessaysubjects(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_getessaysubjects(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_detail(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_detail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_treelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_treelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_subject_save(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_subject_save(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "siftFlag", "delFlag", "level", "parentId", "subPicUrl", "isService", "explain", "isSearch", "subjectName", "status", "type"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/pay/orderpaybill/orderRefund")
def pay_orderpaybill_orderrefund(orderMainId=None, headers=None, **kwargs):
    """
    订单退款接口-Y
    up_time=1675660576

    params: orderMainId :  : 订单id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : null : 
    """
    _method = "GET"
    _url = "/pay/orderpaybill/orderRefund"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderMainId": orderMainId,  # 订单id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_subject import AssertsContentSubject
from service.app_a.apis.content import apis_content_subject


class FunsContentSubject(AssertsContentSubject):
    @allure.step(title="专题-后台App专题文章列表-Y")
    def content_subject_detailessay(self, subjectId="$None$", size=10, subjectName="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/subject/detailEssay
                params: current :  :
                params: size :  :
                params: subjectId :  : Long
                params: subjectName :  :  string
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")
        subjectName = self.get_list_choice(subjectName, list_or_dict=None, key="subjectName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_detailessay(**_kwargs)

        self.assert_content_subject_detailessay(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台App专题新增-Y")
    def content_subject_add(self, level="$None$", parentId="$None$", subPicUrl="$None$", explain="$None$", subjectName="$None$", status="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subject/add
                params: subjectName : string : 专题名称
                params: parentId : string : 父级专题主键
                params: level : number : 专题等级
                params: status : number : 是否可用1：是0：否
                params: explain : string : 说明
                params: type : number : 关联类型
                params: subPicUrl : string : 专题图片
                params: headers : 请求头
        """
        level = self.get_value_choice(level, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        parentId = self.get_value_choice(parentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subPicUrl = self.get_value_choice(subPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        explain = self.get_value_choice(explain, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subjectName = self.get_value_choice(subjectName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_add(**_kwargs)

        self.assert_content_subject_add(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台App删除专题-Y")
    def content_subject_del(self, subjectId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subject/del
                params: subjectId : text :
                params: headers : 请求头
        """
        subjectId = self.get_value_choice(subjectId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_del(**_kwargs)

        self.assert_content_subject_del(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台App移动专题更新-Y")
    def content_subject_mobilesubject(self, subjectId="$None$", serial="$None$", parentId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subject/mobileSubject
                params: subjectId : text : 移动的专题ID
                params: parentId : text : 移动到的一级专题ID
                params: serial : text : 排序
                params: headers : 请求头
        """
        subjectId = self.get_value_choice(subjectId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        serial = self.get_value_choice(serial, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        parentId = self.get_value_choice(parentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_mobilesubject(**_kwargs)

        self.assert_content_subject_mobilesubject(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="文章-发布到下拉数据-Y")
    def content_subject_getessaysubjects(self, _assert=True,  **kwargs):
        """
            url=/content/subject/getEssaySubjects
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_getessaysubjects(**_kwargs)

        self.assert_content_subject_getessaysubjects(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台App查询专题详情-Y")
    def content_subject_detail(self, subjectId="$None$", _assert=True,  **kwargs):
        """
            url=/content/subject/detail
                params: subjectId :  : 广告位主键
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_detail(**_kwargs)

        self.assert_content_subject_detail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台APP专题类型列表-Y")
    def content_subject_treelist(self, _assert=True,  **kwargs):
        """
            url=/content/subject/treeList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_treelist(**_kwargs)

        self.assert_content_subject_treelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台App保存/更新-Y")
    def content_subject_save(self, subjectId="$None$", siftFlag="$None$", delFlag="$None$", level="$None$", parentId="$None$", subPicUrl="$None$", isService="$None$", explain="$None$", isSearch="$None$", subjectName="$None$", status="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/subject/save
                params: subjectId : number :
                params: subjectName : string :
                params: level : number :
                params: delFlag : number :
                params: subPicUrl : string :
                params: explain : string :
                params: status : number :
                params: type : number :
                params: parentId : string : 父ID
                params: siftFlag : number : 是否精选 1是 0否
                params: isService : number : 是否设置客服入口 1是 0否
                params: isSearch : number : 是否配置搜索 0否 1是
                params: headers : 请求头
        """
        subjectId = self.get_value_choice(subjectId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        siftFlag = self.get_value_choice(siftFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        delFlag = self.get_value_choice(delFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        level = self.get_value_choice(level, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        parentId = self.get_value_choice(parentId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subPicUrl = self.get_value_choice(subPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isService = self.get_value_choice(isService, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        explain = self.get_value_choice(explain, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isSearch = self.get_value_choice(isSearch, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        subjectName = self.get_value_choice(subjectName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_subject.content_subject_save(**_kwargs)

        self.assert_content_subject_save(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/admin/spa/getAppId")
def admin_spa_getappid( headers=None, **kwargs):
    """
    获取guc appId
    up_time=1675133803

    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : object : 返回
              appId : string : appid
    """
    _method = "GET"
    _url = "/admin/spa/getAppId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/goods/configure/saveCarConfigure")
def goods_configure_savecarconfigure(processColorList=None, optionalList=None, salesVersionList=None, appearanceColorList=None, interiorColorList=None, headers=None, **kwargs):
    """
    保存车型配置信息-Y
    up_time=1675650535

    params: salesVersionList : array : 销售版本
              configureId : string : 配置ID
              modelId : string : 关联的车型基础信息ID
              configureCode : string : 配置编码
              configureName : string : 配置名称
              saleVersion : string : 销售-版本号
              abbreviationList : array : 缩略图
              gwAbbreviationList : array : 官网缩略图
              defaultCarModelList : array : 默认车型
              gwDefaultCarModelList : array : 官网默认车型
              price : number : 零售价|加价
              sort : number : 前台权重
              versionDesc : string : 版本描述
              partsDesc : string : 配件描述
              status : number : 状态 （1:启用，0：禁用） 默认启用
              type : number : 1:销售版本,2:动力系统,3:外观颜色,4:内饰颜色,5:选装配置
    params: processColorList : array : 套色
              configureId : string : 配置ID
              modelId : string : 车型ID
              configureCode : string : 配置编码
              configureName : string : 配置名称
              saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
              appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
              saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
              modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
              abbreviationList : array : 缩略图
              gwAbbreviationList : array : 官网缩略图
              defaultCarModelList : array : 默认车型
              gwDefaultCarModelList : array : 官网默认车型
              price : number : 加价
              sort : number : 排序
              versionDesc : string : 
              partsDesc : string : 
              status : number : 状态
              type : number : 类型
    params: appearanceColorList : array : 外观颜色
              configureId : string : 配置Id
              modelId : string : 车型ID
              configureCode : string : 配置编码
              configureName : string : 配置名称
              saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
              appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
              saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
              modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
              abbreviationList : array : 缩略图
              gwAbbreviationList : array : 官网缩略图
              defaultCarModelList : array : 默认车型
              gwDefaultCarModelList : array : 官网默认车型
              price : number : 加价
              sort : number : 排序
              versionDesc : string : 
              partsDesc : string : 
              status : number : 状态
              type : number : 类型
    params: interiorColorList : array : 内饰颜色
              configureId : string : 配置ID
              modelId : string : 车型Id
              configureCode : string : 配置编码
              configureName : string : 配置名称
              saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
              appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
              saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
              modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
              abbreviationList : array : 缩略图
              gwAbbreviationList : array : 官网缩略图
              defaultCarModelList : array : 默认车型
              gwDefaultCarModelList : array : 官网默认车型
              price : number : 加价
              sort : number : 排序
              versionDesc : string : 
              partsDesc : string : 
              status : number : 状态
              type : number : 类型
    params: optionalList : array : 选装配件
              configureId : string : 配置ID
              modelId : string : 车型ID
              configureCode : string : 配置编码
              configureName : string : 配置名称
              saleVersionRelation : string : 关联销售版本 ALL代表全部多个版本以英文逗号隔开
              appearanceColorRelation : string : 套色、内饰关联的外观颜色，ALL代表全部多个版本以英文逗号隔开
              saleVersionContain : string : 价格已包含的版本， ALL代表全部多个版本以英文逗号隔开
              modificationName : string : 外观颜色|套色|内饰颜色|选装名称 - 修饰名称
              abbreviationList : array : 缩略图
              gwAbbreviationList : array : 官网缩略图
              defaultCarModelList : array : 默认车型
              gwDefaultCarModelList : array : 官网默认车型
              price : number : 加价
              sort : number : 排序
              versionDesc : string : 
              partsDesc : string : 配件描述
              status : number : 状态 默认启用 1
              type : number : 1:销售版本,2:外观颜色,3:套色,4:内饰颜色,5:选装配置
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/goods/configure/saveCarConfigure"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "salesVersionList": salesVersionList,  # 销售版本
        "processColorList": processColorList,  # 套色
        "appearanceColorList": appearanceColorList,  # 外观颜色
        "interiorColorList": interiorColorList,  # 内饰颜色
        "optionalList": optionalList,  # 选装配件
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/configure/getCarConfigureName")
def goods_configure_getcarconfigurename(modelId=None, headers=None, **kwargs):
    """
    查询配置名称-Y
    up_time=1675652068

    params: modelId :  : 车型Id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 编码
    params: msg : string : 消息
    params: data : object : 数据
              salesVersion : array : 销售版本
              optional : array : 选装
              optionalPackage : array : 选装包
              appearanceColor : array : 外观颜色
    """
    _method = "GET"
    _url = "/goods/configure/getCarConfigureName"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "modelId": modelId,  # 车型Id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/configure/removeCarConfigure")
def goods_configure_removecarconfigure(configureId=None, headers=None, **kwargs):
    """
    车型配置删除-D
    up_time=1675650781

    params: configureId :  : 主键Id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : null : 
    """
    _method = "GET"
    _url = "/goods/configure/removeCarConfigure"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "configureId": configureId,  # 主键Id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/configure/updateCarConfigureStatus")
def goods_configure_updatecarconfigurestatus(configureId=None, headers=None, **kwargs):
    """
    车型配置更改状态-D
    up_time=1675650743

    params: configureId :  : 车型配置Id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "GET"
    _url = "/goods/configure/updateCarConfigureStatus"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "configureId": configureId,  # 车型配置Id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/configure/info")
def goods_configure_info(modelId=None, headers=None, **kwargs):
    """
    车型配置查询（930）-?
    up_time=1675391059

    params: modelId :  : 车型基础ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 编码
    params: msg : string : 信息
    params: data : object : 数据
              interiorColor : array : 内饰颜色
              processColor : array : 套色
              appearanceColor : array : 外观颜色
              salesVersion : array : 销售版本
              optional : array : 选配
    """
    _method = "GET"
    _url = "/goods/configure/info"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "modelId": modelId,  # 车型基础ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/userPoints/exchangeInfo/pageList")
def radarpoints_userpoints_exchangeinfo_pagelist(consigneeName=None, userId=None, size=None, orderStartTime=None, mobile=None, orderEndTime=None, goodsOrderId=None, current=None, headers=None, **kwargs):
    """
    用户中心-兑换明细 - 分页查询
    up_time=1676903335

    params: size :  : 每页大小
    params: current :  : 当前页
    params: userId :  : 用户ID
    params: consigneeName :  : 收货人姓名
    params: goodsOrderId :  : 商品订单
    params: mobile :  : 收货人电话
    params: orderStartTime :  : 下单开始时间
    params: orderEndTime :  : 下单结束时间
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/radarpoints/userPoints/exchangeInfo/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "size": size,  # 每页大小
        "current": current,  # 当前页
        "userId": userId,  # 用户ID
        "consigneeName": consigneeName,  # 收货人姓名
        "goodsOrderId": goodsOrderId,  # 商品订单
        "mobile": mobile,  # 收货人电话
        "orderStartTime": orderStartTime,  # 下单开始时间
        "orderEndTime": orderEndTime,  # 下单结束时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/adjustPoints/adjust/batch/save")
def radarpoints_adjustpoints_adjust_batch_save(file=None, clientNotes=None, adjustNotes=None, redisKey=None, optAbility=None, optAbilityName=None, headers=None, **kwargs):
    """
    积分调整 - 批量调整
    up_time=1677216489

    params: file : file : 导入excel文件
    params: optAbility : text : 调整方式
    params: adjustNotes : text : 调整原因说明
    params: clientNotes : text : 用户端展示
    params: optAbilityName : string : 调整方式枚举
    params: redisKey : string : 缓存键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200成功，其他-失败
    params: msg : string : 提示信息
    params: data : object : 
              checkErrorNum : number : 此接口不使用
              checkSuccessNum : number : 此接口不使用
              executeErrorNum : number : 执行 - 错误数据
              executeSuccessNum : number : 执行 - 成功数据
              list : array : 
    """
    _method = "POST"
    _url = "/radarpoints/adjustPoints/adjust/batch/save"

    _headers = {
        "Content-Type": "multipart/form-data",
    }
    _headers.update({"headers": headers})

    _data = {
        "file": file,  # 导入excel文件
        "optAbility": optAbility,  # 调整方式
        "adjustNotes": adjustNotes,  # 调整原因说明
        "clientNotes": clientNotes,  # 用户端展示
        "optAbilityName": optAbilityName,  # 调整方式枚举
        "redisKey": redisKey,  # 缓存键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/adjustPoints/adjust/batch/import")
def radarpoints_adjustpoints_adjust_batch_import(file=None, clientNotes=None, adjustNotes=None, field_35=None, list=None, field_34=None, headers=None, **kwargs):
    """
    积分调整 - 批量调整 - 导入excel
    up_time=1677216494

    params: file : file : excel文件
    params: adjustNotes : string : 调整原因说明
    params: clientNotes : string : 客户端显示信息
    params: list : array : 成功数据集
              userId : number : 用户id
              adjustTypeName : number : 调整类型名称
              adjustNumber : number : 调整数值
              pointsDepartment : number : 积分归属部门
              DateType : number : 生效时间类型
    params: field_35 : string : 
    params: field_34 : string : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200：成功，其他失败
    params: msg : string : 提示信息
    params: data : object : 
              checkErrorNum : number : Excel校验 - 错误数据
              checkSuccessNum : number : Excel校验 - 成功数据
              executeErrorNum : number : 此接口不使用
              executeSuccessNum : number : 此接口不使用
              list : array : 
    """
    _method = "POST"
    _url = "/radarpoints/adjustPoints/adjust/batch/import"

    _headers = {
        "Content-Type": "multipart/form-data",
    }
    _headers.update({"headers": headers})

    _data = {
        "file": file,  # excel文件
        "adjustNotes": adjustNotes,  # 调整原因说明
        "clientNotes": clientNotes,  # 客户端显示信息
        "list": list,  # 成功数据集
        "field_35": field_35,
        "field_34": field_34,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.pay.asserts_pay_orderpaybill import AssertsPayOrderpaybill
from service.app_a.apis.pay import apis_pay_orderpaybill


class FunsPayOrderpaybill(AssertsPayOrderpaybill):
    @allure.step(title="订单退款接口-Y")
    def pay_orderpaybill_orderrefund(self, orderMainId="$None$", _assert=True,  **kwargs):
        """
            url=/pay/orderpaybill/orderRefund
                params: orderMainId :  : 订单id
                params: headers : 请求头
        """
        orderMainId = self.get_list_choice(orderMainId, list_or_dict=None, key="orderMainId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_pay_orderpaybill.pay_orderpaybill_orderrefund(**_kwargs)

        self.assert_pay_orderpaybill_orderrefund(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/essay/batch")
def essay_batch(essayId=None, batchType=None, headers=None, **kwargs):
    """
    文章-批量操作-Y
    up_time=1675736143

    params: essayId :  : 文章主键
    params: batchType :  : 1：归档2：撤回3：置顶4：取消置顶
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/essay/batch"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "batchType": batchType,  # 1：归档2：撤回3：置顶4：取消置顶
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/essay/queryListCount")
def essay_querylistcount(subjectId=None, keyWord=None, endTime=None, status=None, author=None, essayId=None, startTime=None, headers=None, **kwargs):
    """
    文章-获取列表状态数量-Y
    up_time=1675736107

    params: essayId :  : 文章主键
    params: keyWord :  : 搜索关键字
    params: author :  : 作者
    params: startTime :  : 搜索起始时间
    params: endTime :  : 搜索结束时间
    params: subjectId :  : 专题主键
    params: status :  : 状态
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              toAuditCount : number : 待审核文章数量
              releasedCount : number : 已发布文章数量（预留）
    """
    _method = "GET"
    _url = "/essay/queryListCount"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "essayId": essayId,  # 文章主键
        "keyWord": keyWord,  # 搜索关键字
        "author": author,  # 作者
        "startTime": startTime,  # 搜索起始时间
        "endTime": endTime,  # 搜索结束时间
        "subjectId": subjectId,  # 专题主键
        "status": status,  # 状态
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


